==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/app/actions/togglePermission.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/app/actions/togglePermission", ['module', 'exports', 'require', './types'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports["default"] = togglePermission;

    var _types = require("./types");

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */

    /**
     * @param {import('../../types/ActionKeys').ACTION_KEYS} key
     * @param {boolean} [value]
     */
    function togglePermission(key) {
      var value = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : undefined;
      var action = {
        key: key,
        type: _types.TOGGLE_PERMISSION
      };

      if (typeof value === 'boolean') {
        action.forceNewValue = value;
      }

      return action;
    }
    //# sourceMappingURL=togglePermission.js.map
  }
});
//# sourceMappingURL=togglePermission.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/app/actions/togglePermission.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/app/actions/togglePermission", ['module', 'exports', 'require', './types'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = togglePermission;

    var _types = require("./types");

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */

    /**
     * @param {import('../../types/ActionKeys').ACTION_KEYS} key
     * @param {boolean} [value]
     */
    function togglePermission(key) {
      var value = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : undefined;
      var action = {
        key: key,
        type: _types.TOGGLE_PERMISSION
      };

      if (typeof value === 'boolean') {
        action.forceNewValue = value;
      }

      return action;
    }
    //# sourceMappingURL=togglePermission.js.map
  }
});
//# sourceMappingURL=togglePermission.js.map
